---
sidebar_position: 6
---

# おめでとうございます！

あなたは**Docusaurusの基本**を学び、**初期テンプレート**にいくつかの変更を加えました。

Docusaurusには**さらに多くの機能**があります！

**あと5分**時間がありますか？バージョン管理と国際化についても学んでみましょう。

このチュートリアルで**不明点**や**バグ**がありましたか？[ぜひ報告してください！](https://github.com/facebook/docusaurus/discussions/4610)

## 次のステップは？

- [公式ドキュメント](https://docusaurus.io/)を読む
- [`docusaurus.config.js`](https://docusaurus.io/docs/api/docusaurus-config)でサイト構成を修正する
- [`themeConfig`](https://docusaurus.io/docs/api/themes/configuration)でナビゲーションバーとフッターの項目を追加する
- カスタムの[デザインとレイアウト](https://docusaurus.io/docs/styling-layout)を追加する
- [検索バー](https://docusaurus.io/docs/search)を追加する
- [Docusaurusのショーケース](https://docusaurus.io/showcase)からインスピレーションを得る
- [Docusaurusコミュニティ](https://docusaurus.io/community/support)に参加する
